.. _`appi`:

fairly package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   fairly.client
   fairly.dataset
   fairly.file

Submodules
----------

fairly.diff module
------------------

.. automodule:: fairly.diff
   :members:
   :undoc-members:
   :show-inheritance:

fairly.metadata module
----------------------

.. automodule:: fairly.metadata
   :members:
   :undoc-members:
   :show-inheritance:

fairly.person module
--------------------

.. automodule:: fairly.person
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fairly
   :members:
   :undoc-members:
   :show-inheritance:
